import requests
from .errors import InvalidApiToken


class Client(object):

    def __init__(self, token: str = None):
        self.token = token
        response = requests.get(
            f"https://api.userge.tk/checktoken?api_key={self.token}"
        ).status_code
        if response != 201:
            raise InvalidApiToken("Your Api Token is invalid")
    
    def get_version(self):
        return requests.get("https://api.userge.tk/version")
    
    def get_api_stats(self):
        return requests.get("https://api.userge.tk")
    
    def getban(self, user_id: int):
        return requests.get(f"https://api.userge.tk/ban?api_key={self.token}&user_id={user_id}").json()
    
    def getbans(self):
        return requests.get("https://api.userge.tk/ban")

    def add_ban(self, user_id: int, reason: str):
        data = {
            "api_key": self.token,
            "user_id": user_id,
            "reason": reason
        }

        return requests.post("https://api.userge.tk/ban", data=data).json()
    
    def update_ban(self, user_id: int, reason: str):
        data = {
            "api_key": self.token,
            "user_id": user_id,
            "reason": reason
        }

        return requests.post("https://api.userge.tk/updateban", data=data).json()

    def delete_ban(self, user_id: int):
        data = {
            "api_key": self.token,
            "user_id": user_id
        }

        return requests.delete("https://api.userge.tk/ban", data=data)
    
    def get_me(self):
        data = {"api_key": self.token}
        return requests.get("https://api.userge.tk/token/self", data=data)
    
    def promote_user(self, user_id: int, permssions: list):
        perms = ""
        for i in permssions:
            perms += i + " "
        perms = perms.strip()
        data = {
            "api_key": self.token,
            "user_id": user_id,
            "perms": perms
        }
        return requests.post("https://api.userge.tk/promotetoken", data=data)
    
    def demote_user(self, user_id: int):
        data = {
            "api_key": self.token,
            "user_id": user_id
        }
        return requests.post("https://api.userge.tk/demotetoken", data=data)
    
    def delete_my_token(self):
        data = {
            "api_key": self.token
        }
        return requests.delete("https://api.userge.tk/token", data=data)



import re
import setuptools

with open("UsergeAntiSpamApi/__init__.py", encoding="utf-8") as f:
    version = re.findall(r"__version__ = \"(.+)\"", f.read())[0]

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="UsergeAntiSpamApi",
    version=version,
    author="Krishna-Singhal",
    author_email="ylikehits3@gmail.com",
    description="Wrapper for [Userge AntiSpam API](https://api.userge.tk)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Krishna-Singhal/userge-federation",
    project_urls={
        "Bug Tracker": "https://github.com/Krishna-Singhal/userge-federation/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    install_requires=["requests"],
    packages=['UsergeAntiSpamApi'],
    python_requires=">=3.6",
)
